@@ -42,6 +42,9 @@ for arg in $*; do
 	merge)
 	    merge_script=1
             ;;
+	norandomize)
+	    debug="$debug --no-randomize"
+	    ;;
 	reuse)
 	    preserve_directory=1
 	    ;;
@@ -63,7 +66,7 @@ if [ -z "$preserve_directory" ]; then
     rm -rf ${test_dir}
 fi
 mkdir -p ${test_dir}
-script_file="${script_file} ${debug}"
+script_file="${script_file} ${debug} --test-mode"
 cd ${test_dir}
 set -x +e
 
@@ -75,39 +78,44 @@ set -x +e
 perl -I ${xmltv_lib} ${script_file} --ahdmegkeja > /dev/null 2>&1
 perl -I ${xmltv_lib} ${script_file} --version > /dev/null 2>&1
 perl -I ${xmltv_lib} ${script_file} --description > /dev/null 2>&1
+perl -I ${xmltv_lib} ${script_file} --list-channels --cache  t_fi_cache  > t_fi_channels.xml --quiet 2>t_fi_channels.log
+if [ $? -ne 0 ]; then
+    tail -1 t_fi_channels.log
+    test_failure=1
+fi
 perl -I ${xmltv_lib} ${script_file} --config-file ${script_dir}/test.conf --offset 1 --days 2 --cache  t_fi_cache  > t_fi_1_2.xml --quiet 2>t_fi_1.log
 validate_xml t_fi_1_2.xml
-${xmltv_script}/tv_cat t_fi_1_2.xml > /dev/null 2>t_fi_6.log
+${xmltv_script}/tv_cat t_fi_1_2.xml --output /dev/null 2>t_fi_6.log
 check_log t_fi_6.log
-${xmltv_script}/tv_sort --duplicate-error t_fi_1_2.xml > t_fi_1_2.sorted.xml 2>t_fi_1_2.sort.log
+${xmltv_script}/tv_sort --duplicate-error t_fi_1_2.xml --output t_fi_1_2.sorted.xml 2>t_fi_1_2.sort.log
 check_log t_fi_1_2.sort.log
 perl -I ${xmltv_lib} ${script_file} --config-file ${script_dir}/test.conf --offset 1 --days 1 --cache  t_fi_cache  --output t_fi_1_1.xml  2>t_fi_2.log
 perl -I ${xmltv_lib} ${script_file} --config-file ${script_dir}/test.conf --offset 2 --days 1 --cache  t_fi_cache  > t_fi_2_1.xml 2>t_fi_3.log
 perl -I ${xmltv_lib} ${script_file} --config-file ${script_dir}/test.conf --offset 1 --days 2 --cache  t_fi_cache  --quiet --output t_fi_4.xml 2>t_fi_4.log
-${xmltv_script}/tv_cat t_fi_1_1.xml t_fi_2_1.xml > t_fi_1_2-2.xml 2>t_fi_5.log
+${xmltv_script}/tv_cat t_fi_1_1.xml t_fi_2_1.xml --output t_fi_1_2-2.xml 2>t_fi_5.log
 check_log t_fi_5.log
-${xmltv_script}/tv_sort --duplicate-error t_fi_1_2-2.xml > t_fi_1_2-2.sorted.xml 2>t_fi_7.log
+${xmltv_script}/tv_sort --duplicate-error t_fi_1_2-2.xml --output t_fi_1_2-2.sorted.xml 2>t_fi_7.log
 check_log t_fi_7.log
 diff t_fi_1_2.sorted.xml t_fi_1_2-2.sorted.xml > t_fi__1_2.diff
 check_log t_fi__1_2.diff
 
 #
-# Modified test run with 9 days and modified test.conf
+# Modified test run with 7 days and modified test.conf
 #
-perl -pe 's/^#(channel\s+(?:4|5|6|7|8|9|10|11|12|.+\.yle|.+\.telvis|.+\.tv\.nyt|.+\.mtv3)\..+)/$1/' <${script_dir}/test.conf >${test_dir}/test.conf
-perl -I ${xmltv_lib} ${script_file} --config-file ${test_dir}/test.conf --offset 1 --days 9 --cache  t_fi_cache  >t_fi_full_10.xml --quiet 2>t_fi_full.log
-validate_xml t_fi_full_10.xml
-for d in $(seq 1 9); do
+perl -pe 's/^#channel\s+/channel /' <${script_dir}/test.conf >${test_dir}/test.conf
+perl -I ${xmltv_lib} ${script_file} --config-file ${test_dir}/test.conf --offset 1 --days 7 --cache  t_fi_cache  >t_fi_full_7.xml --quiet 2>t_fi_full.log
+validate_xml t_fi_full_7.xml
+for d in $(seq 1 7); do
     perl -I ${xmltv_lib} ${script_file} --config-file ${test_dir}/test.conf --offset $d --days 1 --cache  t_fi_cache  >t_fi_single_$d.xml --quiet 2>>t_fi_single.log
 done
-${xmltv_script}/tv_cat t_fi_full_10.xml > /dev/null 2>t_fi_output.log
-${xmltv_script}/tv_sort --duplicate-error t_fi_full_10.xml > t_fi_full_10.sorted.xml 2>>t_fi_output.log
+${xmltv_script}/tv_cat t_fi_full_7.xml --output /dev/null 2>t_fi_output.log
+${xmltv_script}/tv_sort --duplicate-error t_fi_full_7.xml --output t_fi_full_7.sorted.xml 2>>t_fi_output.log
 check_log t_fi_output.log
-${xmltv_script}/tv_cat t_fi_single_*.xml >t_fi_full_10-2.xml 2>t_fi_output-2.log
-${xmltv_script}/tv_sort --duplicate-error t_fi_full_10-2.xml > t_fi_full_10-2.sorted.xml 2>>t_fi_output-2.log
+${xmltv_script}/tv_cat t_fi_single_*.xml --output t_fi_full_7-2.xml 2>t_fi_output-2.log
+${xmltv_script}/tv_sort --duplicate-error t_fi_full_7-2.xml --output t_fi_full_7-2.sorted.xml 2>>t_fi_output-2.log
 check_log t_fi_output-2.log
-diff t_fi_full_10.sorted.xml t_fi_full_10-2.sorted.xml >t_fi__10.diff
-check_log t_fi__10.diff
+diff t_fi_full_7.sorted.xml t_fi_full_7-2.sorted.xml >t_fi__7.diff
+check_log t_fi__7.diff
 
 #
 # All tests done
