@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_opt.pl,v 1.28 2014/09/20 06:11:43 rmeden Exp $
+# $Id: exe_opt.pl,v 1.30 2015/07/12 00:59:01 knowledgejunkie Exp $
 #
 # This is a simple script to generate options so PerlApp can make the EXE
 # it needs time values, so might as well put it in a perl script!
@@ -21,6 +21,9 @@ print '-nologo
 -add DateTime::
 -add Params::Validate::**
 -add Date::Language::
+-add Class::MethodMaker::
+-add Class::MethodMaker::Engine
+-add arybase
 -bind=libexpat-1_.dll[file=C:\strawberry\c\bin\libexpat-1_.dll,extract]
 -bind=libxml2-2_.dll[file=C:\strawberry\c\bin\libxml2-2_.dll,extract]
 -bind=libiconv-2_.dll[file=C:\strawberry\c\bin\libiconv-2_.dll,extract]
@@ -56,7 +59,7 @@ foreach $dir (@Encoding_Path) {
        print "-bind=XML/Parser/Encodings/${file}[file=$dir/${file},extract]\n";
     }
 }
-       
+
 #
 # put date in file version field
 #
